#
# spec file for package python-opengl-accelerate
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define tarname PyOpenGL-accelerate
%define _version 3.1.9
%{?sle15_python_module_pythons}
Name:           python-opengl-accelerate
Version:        %{_version}
Release:        2.1
Summary:        Acceleration for python-opengl
License:        BSD-3-Clause
URL:            http://pyopengl.sourceforge.net
Source0:        %{tarname}-%{_version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module opengl >= %{version}}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module numpy-devel if (%python-base without python36-base)}
Recommends:     python-numpy
Requires:       python-opengl >= %{version}
Provides:       python-PyOpenGL_accelerate = %{version}-%{release}
%python_subpackages

%description
This set of C (Cython) extensions provides acceleration of common
operations for slow points in PyOpenGL 3.x. For code which uses large
arrays extensively speed-up is around 10% compared to unaccelerated
code.

%prep
%autosetup -p1 -n %{tarname}-%{_version}

# _service pulldown creates %%{tarname}-%%{_version}/accelerate/<required files>,
# move them to root of build area and remove 'accelerate' directory
# to continue as normal.
mv accelerate/* ./
rmdir accelerate

%build
export CFLAGS="%{optflags} -DGLX_GLXEXT_LEGACY"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license license.txt
%doc README.md
%{python_sitearch}/OpenGL_accelerate/
%{python_sitearch}/[Pp]y[Oo]pen[Gg][Ll]_accelerate-%{version}.dist-info

%changelog
* Fri Jul  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Mon Apr 28 2025 Markéta Machová <mmachova@suse.com>
- update to 3.1.9
  * Reduce the number of iterations in memory leak test to avoid JIT
    triggering
  * Cleanup formatting in a few modules
  * Don't bomb out during egl test when there's no egl devices
  * Regenerated C wrappers with latest Cython
  * Numpy intp type for latest numpy
  * Fix ctypes FormatHandler for Python 3.12+
  * More changes, see upstream commits
- Drop merged 112.patch and numpy2.patch
* Tue Sep 10 2024 Markéta Machová <mmachova@suse.com>
- Add upstream patch numpy2.patch to fix compatibility with Numpy 2
  * https://github.com/mcfletch/pyopengl/commit/f897b0ed75c00d4c524be4689683a334832217ac
* Wed Jun  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix build with GCC 14
  * https://github.com/mcfletch/pyopengl/pull/112.patch
* Thu Jan  4 2024 Markéta Machová <mmachova@suse.com>
- Drop test_numpyaccel.py and test_arraydatatypeaccel.py as they are
  already included in the downloaded tarball
* Wed Jan  3 2024 Scott Bradnick <scott.bradnick@suse.com>
- Update to 3.1.7
- Changing to /master/ vs. hash for Source[1,2] files
* Fri Apr  1 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding _service file
- Cleaning up Source0 declaration since PyPI doesn't have a tarball
- Updating hash for 'accelerate/test' Source[1,2]
- Adding code to %%prep section to deal w/ how _service pulls down
  files for the gzip'd tarball
* Thu Mar 31 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to 3.1.6
  * Pulled directly from https://github.com/mcfletch/pyopengl since
    pypi.org (via py2pack fetch) doesn't have this version available.
  * Seems that some packages which use PyOpenGL and accelerate have
    a soft requirement that they're the same version.
* Tue Mar 23 2021 Ben Greiner <code@bnavigator.de>
- Don't build the numpy formathandler for python36.
  NumPy is optional and not available for python36 on Tumbleweed.
- Add test files test_arraydatatypeaccel.py and test_numpyaccel.py
* Fri Jul 17 2020 Markus Ebner <info@ebner-markus.de>
- Update to 3.1.5
  * This aligns python3-opengl-accelerate with python3-opengl, which
    is required by some other packages
  * no real changelog
- Drop patch commit1080.patch, included upstream
- Drop shipped pxd files, included upstream (https://github.com/mcfletch/pyopengl/commit/d401885f6a1c61213058a96e050eb45ee6189b7c)
* Mon Aug 19 2019 John Vandenberg <jayvdb@gmail.com>
- Add commit1080.patch to make source compatible with opengl 3.1.3b2
  needed for Python 3.7 compatibility
- Add wrapper.pxd and formathandler.pxd needed to rebuild from source
* Thu Oct 25 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 3.1.3b1:
  * no real changelog
* Mon Jun  5 2017 aloisio@gmx.com
- Update to version 3.1.1a1
- Converted to single-spec
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 3.1.0
  * no changelog
* Thu Apr 18 2013 toddrme2178@gmail.com
- Initial version
